@@ -5,7 +5,15 @@ typedef struct
   float b;
 }str_t;
 
+#ifdef STACK_SIZE
+#if STACK_SIZE > 8000
 #define N 1000
+#else
+#define N (STACK_SIZE/8)
+#endif
+#else
+#define N 1000
+#endif
 
 int
 main ()
@@ -13,6 +21,11 @@ main ()
   int i, sum;
 
   str_t * p = malloc (N * sizeof (str_t));
+  if (p == NULL)
+    return 0;
+  for (i = 0; i < N; i++)
+    p[i].b = i;
+
   for (i = 0; i < N; i++)
     p[i].a = p[i].b + 1;
 
